SparseBFSSearcher
=================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: SparseBFSSearcher
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SparseBFSSearcher.__call__
      ~SparseBFSSearcher.bfs
      ~SparseBFSSearcher.create_adjacency
      ~SparseBFSSearcher.iter_extra_repr
      ~SparseBFSSearcher.select

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: bfs
   .. automethod:: create_adjacency
   .. automethod:: iter_extra_repr
   .. automethod:: select
